// This file was generated by gir (https://github.com/gtk-rs/gir)
// from gir-files (https://github.com/gtk-rs/gir-files)
// DO NOT EDIT

#include "manual.h"
#include <stdalign.h>
#include <stdio.h>

int main() {
    printf("%s;%zu;%zu\n", "GtkAboutDialog", sizeof(GtkAboutDialog), alignof(GtkAboutDialog));
    printf("%s;%zu;%zu\n", "GtkAboutDialogClass", sizeof(GtkAboutDialogClass), alignof(GtkAboutDialogClass));
    printf("%s;%zu;%zu\n", "GtkAccelFlags", sizeof(GtkAccelFlags), alignof(GtkAccelFlags));
    printf("%s;%zu;%zu\n", "GtkAccelGroup", sizeof(GtkAccelGroup), alignof(GtkAccelGroup));
    printf("%s;%zu;%zu\n", "GtkAccelGroupClass", sizeof(GtkAccelGroupClass), alignof(GtkAccelGroupClass));
    printf("%s;%zu;%zu\n", "GtkAccelGroupEntry", sizeof(GtkAccelGroupEntry), alignof(GtkAccelGroupEntry));
    printf("%s;%zu;%zu\n", "GtkAccelKey", sizeof(GtkAccelKey), alignof(GtkAccelKey));
    printf("%s;%zu;%zu\n", "GtkAccelLabel", sizeof(GtkAccelLabel), alignof(GtkAccelLabel));
    printf("%s;%zu;%zu\n", "GtkAccelLabelClass", sizeof(GtkAccelLabelClass), alignof(GtkAccelLabelClass));
    printf("%s;%zu;%zu\n", "GtkAccessible", sizeof(GtkAccessible), alignof(GtkAccessible));
    printf("%s;%zu;%zu\n", "GtkAccessibleClass", sizeof(GtkAccessibleClass), alignof(GtkAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkAction", sizeof(GtkAction), alignof(GtkAction));
    printf("%s;%zu;%zu\n", "GtkActionBar", sizeof(GtkActionBar), alignof(GtkActionBar));
    printf("%s;%zu;%zu\n", "GtkActionBarClass", sizeof(GtkActionBarClass), alignof(GtkActionBarClass));
    printf("%s;%zu;%zu\n", "GtkActionClass", sizeof(GtkActionClass), alignof(GtkActionClass));
    printf("%s;%zu;%zu\n", "GtkActionEntry", sizeof(GtkActionEntry), alignof(GtkActionEntry));
    printf("%s;%zu;%zu\n", "GtkActionGroup", sizeof(GtkActionGroup), alignof(GtkActionGroup));
    printf("%s;%zu;%zu\n", "GtkActionGroupClass", sizeof(GtkActionGroupClass), alignof(GtkActionGroupClass));
    printf("%s;%zu;%zu\n", "GtkActionableInterface", sizeof(GtkActionableInterface), alignof(GtkActionableInterface));
    printf("%s;%zu;%zu\n", "GtkActivatableIface", sizeof(GtkActivatableIface), alignof(GtkActivatableIface));
    printf("%s;%zu;%zu\n", "GtkAdjustment", sizeof(GtkAdjustment), alignof(GtkAdjustment));
    printf("%s;%zu;%zu\n", "GtkAdjustmentClass", sizeof(GtkAdjustmentClass), alignof(GtkAdjustmentClass));
    printf("%s;%zu;%zu\n", "GtkAlign", sizeof(GtkAlign), alignof(GtkAlign));
    printf("%s;%zu;%zu\n", "GtkAlignment", sizeof(GtkAlignment), alignof(GtkAlignment));
    printf("%s;%zu;%zu\n", "GtkAlignmentClass", sizeof(GtkAlignmentClass), alignof(GtkAlignmentClass));
    printf("%s;%zu;%zu\n", "GtkAllocation", sizeof(GtkAllocation), alignof(GtkAllocation));
    printf("%s;%zu;%zu\n", "GtkAppChooserButton", sizeof(GtkAppChooserButton), alignof(GtkAppChooserButton));
    printf("%s;%zu;%zu\n", "GtkAppChooserButtonClass", sizeof(GtkAppChooserButtonClass), alignof(GtkAppChooserButtonClass));
    printf("%s;%zu;%zu\n", "GtkAppChooserDialog", sizeof(GtkAppChooserDialog), alignof(GtkAppChooserDialog));
    printf("%s;%zu;%zu\n", "GtkAppChooserDialogClass", sizeof(GtkAppChooserDialogClass), alignof(GtkAppChooserDialogClass));
    printf("%s;%zu;%zu\n", "GtkAppChooserWidget", sizeof(GtkAppChooserWidget), alignof(GtkAppChooserWidget));
    printf("%s;%zu;%zu\n", "GtkAppChooserWidgetClass", sizeof(GtkAppChooserWidgetClass), alignof(GtkAppChooserWidgetClass));
    printf("%s;%zu;%zu\n", "GtkApplication", sizeof(GtkApplication), alignof(GtkApplication));
    printf("%s;%zu;%zu\n", "GtkApplicationClass", sizeof(GtkApplicationClass), alignof(GtkApplicationClass));
    printf("%s;%zu;%zu\n", "GtkApplicationInhibitFlags", sizeof(GtkApplicationInhibitFlags), alignof(GtkApplicationInhibitFlags));
    printf("%s;%zu;%zu\n", "GtkApplicationWindow", sizeof(GtkApplicationWindow), alignof(GtkApplicationWindow));
    printf("%s;%zu;%zu\n", "GtkApplicationWindowClass", sizeof(GtkApplicationWindowClass), alignof(GtkApplicationWindowClass));
    printf("%s;%zu;%zu\n", "GtkArrow", sizeof(GtkArrow), alignof(GtkArrow));
    printf("%s;%zu;%zu\n", "GtkArrowAccessible", sizeof(GtkArrowAccessible), alignof(GtkArrowAccessible));
    printf("%s;%zu;%zu\n", "GtkArrowAccessibleClass", sizeof(GtkArrowAccessibleClass), alignof(GtkArrowAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkArrowClass", sizeof(GtkArrowClass), alignof(GtkArrowClass));
    printf("%s;%zu;%zu\n", "GtkArrowPlacement", sizeof(GtkArrowPlacement), alignof(GtkArrowPlacement));
    printf("%s;%zu;%zu\n", "GtkArrowType", sizeof(GtkArrowType), alignof(GtkArrowType));
    printf("%s;%zu;%zu\n", "GtkAspectFrame", sizeof(GtkAspectFrame), alignof(GtkAspectFrame));
    printf("%s;%zu;%zu\n", "GtkAspectFrameClass", sizeof(GtkAspectFrameClass), alignof(GtkAspectFrameClass));
    printf("%s;%zu;%zu\n", "GtkAssistant", sizeof(GtkAssistant), alignof(GtkAssistant));
    printf("%s;%zu;%zu\n", "GtkAssistantClass", sizeof(GtkAssistantClass), alignof(GtkAssistantClass));
    printf("%s;%zu;%zu\n", "GtkAssistantPageType", sizeof(GtkAssistantPageType), alignof(GtkAssistantPageType));
    printf("%s;%zu;%zu\n", "GtkAttachOptions", sizeof(GtkAttachOptions), alignof(GtkAttachOptions));
    printf("%s;%zu;%zu\n", "GtkBaselinePosition", sizeof(GtkBaselinePosition), alignof(GtkBaselinePosition));
    printf("%s;%zu;%zu\n", "GtkBin", sizeof(GtkBin), alignof(GtkBin));
    printf("%s;%zu;%zu\n", "GtkBinClass", sizeof(GtkBinClass), alignof(GtkBinClass));
    printf("%s;%zu;%zu\n", "GtkBindingArg", sizeof(GtkBindingArg), alignof(GtkBindingArg));
    printf("%s;%zu;%zu\n", "GtkBindingSet", sizeof(GtkBindingSet), alignof(GtkBindingSet));
    printf("%s;%zu;%zu\n", "GtkBindingSignal", sizeof(GtkBindingSignal), alignof(GtkBindingSignal));
    printf("%s;%zu;%zu\n", "GtkBooleanCellAccessible", sizeof(GtkBooleanCellAccessible), alignof(GtkBooleanCellAccessible));
    printf("%s;%zu;%zu\n", "GtkBooleanCellAccessibleClass", sizeof(GtkBooleanCellAccessibleClass), alignof(GtkBooleanCellAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkBorder", sizeof(GtkBorder), alignof(GtkBorder));
    printf("%s;%zu;%zu\n", "GtkBorderStyle", sizeof(GtkBorderStyle), alignof(GtkBorderStyle));
    printf("%s;%zu;%zu\n", "GtkBox", sizeof(GtkBox), alignof(GtkBox));
    printf("%s;%zu;%zu\n", "GtkBoxClass", sizeof(GtkBoxClass), alignof(GtkBoxClass));
    printf("%s;%zu;%zu\n", "GtkBuildableIface", sizeof(GtkBuildableIface), alignof(GtkBuildableIface));
    printf("%s;%zu;%zu\n", "GtkBuilder", sizeof(GtkBuilder), alignof(GtkBuilder));
    printf("%s;%zu;%zu\n", "GtkBuilderClass", sizeof(GtkBuilderClass), alignof(GtkBuilderClass));
    printf("%s;%zu;%zu\n", "GtkBuilderError", sizeof(GtkBuilderError), alignof(GtkBuilderError));
    printf("%s;%zu;%zu\n", "GtkButton", sizeof(GtkButton), alignof(GtkButton));
    printf("%s;%zu;%zu\n", "GtkButtonAccessible", sizeof(GtkButtonAccessible), alignof(GtkButtonAccessible));
    printf("%s;%zu;%zu\n", "GtkButtonAccessibleClass", sizeof(GtkButtonAccessibleClass), alignof(GtkButtonAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkButtonBox", sizeof(GtkButtonBox), alignof(GtkButtonBox));
    printf("%s;%zu;%zu\n", "GtkButtonBoxClass", sizeof(GtkButtonBoxClass), alignof(GtkButtonBoxClass));
    printf("%s;%zu;%zu\n", "GtkButtonBoxStyle", sizeof(GtkButtonBoxStyle), alignof(GtkButtonBoxStyle));
    printf("%s;%zu;%zu\n", "GtkButtonClass", sizeof(GtkButtonClass), alignof(GtkButtonClass));
    printf("%s;%zu;%zu\n", "GtkButtonRole", sizeof(GtkButtonRole), alignof(GtkButtonRole));
    printf("%s;%zu;%zu\n", "GtkButtonsType", sizeof(GtkButtonsType), alignof(GtkButtonsType));
    printf("%s;%zu;%zu\n", "GtkCalendar", sizeof(GtkCalendar), alignof(GtkCalendar));
    printf("%s;%zu;%zu\n", "GtkCalendarClass", sizeof(GtkCalendarClass), alignof(GtkCalendarClass));
    printf("%s;%zu;%zu\n", "GtkCalendarDisplayOptions", sizeof(GtkCalendarDisplayOptions), alignof(GtkCalendarDisplayOptions));
    printf("%s;%zu;%zu\n", "GtkCellAccessible", sizeof(GtkCellAccessible), alignof(GtkCellAccessible));
    printf("%s;%zu;%zu\n", "GtkCellAccessibleClass", sizeof(GtkCellAccessibleClass), alignof(GtkCellAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkCellAccessibleParentIface", sizeof(GtkCellAccessibleParentIface), alignof(GtkCellAccessibleParentIface));
    printf("%s;%zu;%zu\n", "GtkCellArea", sizeof(GtkCellArea), alignof(GtkCellArea));
    printf("%s;%zu;%zu\n", "GtkCellAreaBox", sizeof(GtkCellAreaBox), alignof(GtkCellAreaBox));
    printf("%s;%zu;%zu\n", "GtkCellAreaBoxClass", sizeof(GtkCellAreaBoxClass), alignof(GtkCellAreaBoxClass));
    printf("%s;%zu;%zu\n", "GtkCellAreaClass", sizeof(GtkCellAreaClass), alignof(GtkCellAreaClass));
    printf("%s;%zu;%zu\n", "GtkCellAreaContext", sizeof(GtkCellAreaContext), alignof(GtkCellAreaContext));
    printf("%s;%zu;%zu\n", "GtkCellAreaContextClass", sizeof(GtkCellAreaContextClass), alignof(GtkCellAreaContextClass));
    printf("%s;%zu;%zu\n", "GtkCellEditableIface", sizeof(GtkCellEditableIface), alignof(GtkCellEditableIface));
    printf("%s;%zu;%zu\n", "GtkCellLayoutIface", sizeof(GtkCellLayoutIface), alignof(GtkCellLayoutIface));
    printf("%s;%zu;%zu\n", "GtkCellRenderer", sizeof(GtkCellRenderer), alignof(GtkCellRenderer));
    printf("%s;%zu;%zu\n", "GtkCellRendererAccel", sizeof(GtkCellRendererAccel), alignof(GtkCellRendererAccel));
    printf("%s;%zu;%zu\n", "GtkCellRendererAccelClass", sizeof(GtkCellRendererAccelClass), alignof(GtkCellRendererAccelClass));
    printf("%s;%zu;%zu\n", "GtkCellRendererAccelMode", sizeof(GtkCellRendererAccelMode), alignof(GtkCellRendererAccelMode));
    printf("%s;%zu;%zu\n", "GtkCellRendererClass", sizeof(GtkCellRendererClass), alignof(GtkCellRendererClass));
    printf("%s;%zu;%zu\n", "GtkCellRendererCombo", sizeof(GtkCellRendererCombo), alignof(GtkCellRendererCombo));
    printf("%s;%zu;%zu\n", "GtkCellRendererComboClass", sizeof(GtkCellRendererComboClass), alignof(GtkCellRendererComboClass));
    printf("%s;%zu;%zu\n", "GtkCellRendererMode", sizeof(GtkCellRendererMode), alignof(GtkCellRendererMode));
    printf("%s;%zu;%zu\n", "GtkCellRendererPixbuf", sizeof(GtkCellRendererPixbuf), alignof(GtkCellRendererPixbuf));
    printf("%s;%zu;%zu\n", "GtkCellRendererPixbufClass", sizeof(GtkCellRendererPixbufClass), alignof(GtkCellRendererPixbufClass));
    printf("%s;%zu;%zu\n", "GtkCellRendererProgress", sizeof(GtkCellRendererProgress), alignof(GtkCellRendererProgress));
    printf("%s;%zu;%zu\n", "GtkCellRendererProgressClass", sizeof(GtkCellRendererProgressClass), alignof(GtkCellRendererProgressClass));
    printf("%s;%zu;%zu\n", "GtkCellRendererSpin", sizeof(GtkCellRendererSpin), alignof(GtkCellRendererSpin));
    printf("%s;%zu;%zu\n", "GtkCellRendererSpinClass", sizeof(GtkCellRendererSpinClass), alignof(GtkCellRendererSpinClass));
    printf("%s;%zu;%zu\n", "GtkCellRendererSpinner", sizeof(GtkCellRendererSpinner), alignof(GtkCellRendererSpinner));
    printf("%s;%zu;%zu\n", "GtkCellRendererSpinnerClass", sizeof(GtkCellRendererSpinnerClass), alignof(GtkCellRendererSpinnerClass));
    printf("%s;%zu;%zu\n", "GtkCellRendererState", sizeof(GtkCellRendererState), alignof(GtkCellRendererState));
    printf("%s;%zu;%zu\n", "GtkCellRendererText", sizeof(GtkCellRendererText), alignof(GtkCellRendererText));
    printf("%s;%zu;%zu\n", "GtkCellRendererTextClass", sizeof(GtkCellRendererTextClass), alignof(GtkCellRendererTextClass));
    printf("%s;%zu;%zu\n", "GtkCellRendererToggle", sizeof(GtkCellRendererToggle), alignof(GtkCellRendererToggle));
    printf("%s;%zu;%zu\n", "GtkCellRendererToggleClass", sizeof(GtkCellRendererToggleClass), alignof(GtkCellRendererToggleClass));
    printf("%s;%zu;%zu\n", "GtkCellView", sizeof(GtkCellView), alignof(GtkCellView));
    printf("%s;%zu;%zu\n", "GtkCellViewClass", sizeof(GtkCellViewClass), alignof(GtkCellViewClass));
    printf("%s;%zu;%zu\n", "GtkCheckButton", sizeof(GtkCheckButton), alignof(GtkCheckButton));
    printf("%s;%zu;%zu\n", "GtkCheckButtonClass", sizeof(GtkCheckButtonClass), alignof(GtkCheckButtonClass));
    printf("%s;%zu;%zu\n", "GtkCheckMenuItem", sizeof(GtkCheckMenuItem), alignof(GtkCheckMenuItem));
    printf("%s;%zu;%zu\n", "GtkCheckMenuItemAccessible", sizeof(GtkCheckMenuItemAccessible), alignof(GtkCheckMenuItemAccessible));
    printf("%s;%zu;%zu\n", "GtkCheckMenuItemAccessibleClass", sizeof(GtkCheckMenuItemAccessibleClass), alignof(GtkCheckMenuItemAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkCheckMenuItemClass", sizeof(GtkCheckMenuItemClass), alignof(GtkCheckMenuItemClass));
    printf("%s;%zu;%zu\n", "GtkColorButton", sizeof(GtkColorButton), alignof(GtkColorButton));
    printf("%s;%zu;%zu\n", "GtkColorButtonClass", sizeof(GtkColorButtonClass), alignof(GtkColorButtonClass));
    printf("%s;%zu;%zu\n", "GtkColorChooserDialog", sizeof(GtkColorChooserDialog), alignof(GtkColorChooserDialog));
    printf("%s;%zu;%zu\n", "GtkColorChooserDialogClass", sizeof(GtkColorChooserDialogClass), alignof(GtkColorChooserDialogClass));
    printf("%s;%zu;%zu\n", "GtkColorChooserInterface", sizeof(GtkColorChooserInterface), alignof(GtkColorChooserInterface));
    printf("%s;%zu;%zu\n", "GtkColorChooserWidget", sizeof(GtkColorChooserWidget), alignof(GtkColorChooserWidget));
    printf("%s;%zu;%zu\n", "GtkColorChooserWidgetClass", sizeof(GtkColorChooserWidgetClass), alignof(GtkColorChooserWidgetClass));
    printf("%s;%zu;%zu\n", "GtkColorSelection", sizeof(GtkColorSelection), alignof(GtkColorSelection));
    printf("%s;%zu;%zu\n", "GtkColorSelectionClass", sizeof(GtkColorSelectionClass), alignof(GtkColorSelectionClass));
    printf("%s;%zu;%zu\n", "GtkColorSelectionDialog", sizeof(GtkColorSelectionDialog), alignof(GtkColorSelectionDialog));
    printf("%s;%zu;%zu\n", "GtkColorSelectionDialogClass", sizeof(GtkColorSelectionDialogClass), alignof(GtkColorSelectionDialogClass));
    printf("%s;%zu;%zu\n", "GtkComboBox", sizeof(GtkComboBox), alignof(GtkComboBox));
    printf("%s;%zu;%zu\n", "GtkComboBoxAccessible", sizeof(GtkComboBoxAccessible), alignof(GtkComboBoxAccessible));
    printf("%s;%zu;%zu\n", "GtkComboBoxAccessibleClass", sizeof(GtkComboBoxAccessibleClass), alignof(GtkComboBoxAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkComboBoxClass", sizeof(GtkComboBoxClass), alignof(GtkComboBoxClass));
    printf("%s;%zu;%zu\n", "GtkComboBoxText", sizeof(GtkComboBoxText), alignof(GtkComboBoxText));
    printf("%s;%zu;%zu\n", "GtkComboBoxTextClass", sizeof(GtkComboBoxTextClass), alignof(GtkComboBoxTextClass));
    printf("%s;%zu;%zu\n", "GtkContainer", sizeof(GtkContainer), alignof(GtkContainer));
    printf("%s;%zu;%zu\n", "GtkContainerAccessible", sizeof(GtkContainerAccessible), alignof(GtkContainerAccessible));
    printf("%s;%zu;%zu\n", "GtkContainerAccessibleClass", sizeof(GtkContainerAccessibleClass), alignof(GtkContainerAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkContainerCellAccessible", sizeof(GtkContainerCellAccessible), alignof(GtkContainerCellAccessible));
    printf("%s;%zu;%zu\n", "GtkContainerCellAccessibleClass", sizeof(GtkContainerCellAccessibleClass), alignof(GtkContainerCellAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkContainerClass", sizeof(GtkContainerClass), alignof(GtkContainerClass));
    printf("%s;%zu;%zu\n", "GtkCornerType", sizeof(GtkCornerType), alignof(GtkCornerType));
    printf("%s;%zu;%zu\n", "GtkCssProvider", sizeof(GtkCssProvider), alignof(GtkCssProvider));
    printf("%s;%zu;%zu\n", "GtkCssProviderClass", sizeof(GtkCssProviderClass), alignof(GtkCssProviderClass));
    printf("%s;%zu;%zu\n", "GtkCssProviderError", sizeof(GtkCssProviderError), alignof(GtkCssProviderError));
    printf("%s;%zu;%zu\n", "GtkCssSectionType", sizeof(GtkCssSectionType), alignof(GtkCssSectionType));
    printf("%s;%zu;%zu\n", "GtkDebugFlag", sizeof(GtkDebugFlag), alignof(GtkDebugFlag));
    printf("%s;%zu;%zu\n", "GtkDeleteType", sizeof(GtkDeleteType), alignof(GtkDeleteType));
    printf("%s;%zu;%zu\n", "GtkDestDefaults", sizeof(GtkDestDefaults), alignof(GtkDestDefaults));
    printf("%s;%zu;%zu\n", "GtkDialog", sizeof(GtkDialog), alignof(GtkDialog));
    printf("%s;%zu;%zu\n", "GtkDialogClass", sizeof(GtkDialogClass), alignof(GtkDialogClass));
    printf("%s;%zu;%zu\n", "GtkDialogFlags", sizeof(GtkDialogFlags), alignof(GtkDialogFlags));
    printf("%s;%zu;%zu\n", "GtkDirectionType", sizeof(GtkDirectionType), alignof(GtkDirectionType));
    printf("%s;%zu;%zu\n", "GtkDragResult", sizeof(GtkDragResult), alignof(GtkDragResult));
    printf("%s;%zu;%zu\n", "GtkDrawingArea", sizeof(GtkDrawingArea), alignof(GtkDrawingArea));
    printf("%s;%zu;%zu\n", "GtkDrawingAreaClass", sizeof(GtkDrawingAreaClass), alignof(GtkDrawingAreaClass));
    printf("%s;%zu;%zu\n", "GtkEditableInterface", sizeof(GtkEditableInterface), alignof(GtkEditableInterface));
    printf("%s;%zu;%zu\n", "GtkEntry", sizeof(GtkEntry), alignof(GtkEntry));
    printf("%s;%zu;%zu\n", "GtkEntryAccessible", sizeof(GtkEntryAccessible), alignof(GtkEntryAccessible));
    printf("%s;%zu;%zu\n", "GtkEntryAccessibleClass", sizeof(GtkEntryAccessibleClass), alignof(GtkEntryAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkEntryBuffer", sizeof(GtkEntryBuffer), alignof(GtkEntryBuffer));
    printf("%s;%zu;%zu\n", "GtkEntryBufferClass", sizeof(GtkEntryBufferClass), alignof(GtkEntryBufferClass));
    printf("%s;%zu;%zu\n", "GtkEntryClass", sizeof(GtkEntryClass), alignof(GtkEntryClass));
    printf("%s;%zu;%zu\n", "GtkEntryCompletion", sizeof(GtkEntryCompletion), alignof(GtkEntryCompletion));
    printf("%s;%zu;%zu\n", "GtkEntryCompletionClass", sizeof(GtkEntryCompletionClass), alignof(GtkEntryCompletionClass));
    printf("%s;%zu;%zu\n", "GtkEntryIconPosition", sizeof(GtkEntryIconPosition), alignof(GtkEntryIconPosition));
    printf("%s;%zu;%zu\n", "GtkEventBox", sizeof(GtkEventBox), alignof(GtkEventBox));
    printf("%s;%zu;%zu\n", "GtkEventBoxClass", sizeof(GtkEventBoxClass), alignof(GtkEventBoxClass));
    printf("%s;%zu;%zu\n", "GtkEventControllerScrollFlags", sizeof(GtkEventControllerScrollFlags), alignof(GtkEventControllerScrollFlags));
    printf("%s;%zu;%zu\n", "GtkEventSequenceState", sizeof(GtkEventSequenceState), alignof(GtkEventSequenceState));
    printf("%s;%zu;%zu\n", "GtkExpander", sizeof(GtkExpander), alignof(GtkExpander));
    printf("%s;%zu;%zu\n", "GtkExpanderAccessible", sizeof(GtkExpanderAccessible), alignof(GtkExpanderAccessible));
    printf("%s;%zu;%zu\n", "GtkExpanderAccessibleClass", sizeof(GtkExpanderAccessibleClass), alignof(GtkExpanderAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkExpanderClass", sizeof(GtkExpanderClass), alignof(GtkExpanderClass));
    printf("%s;%zu;%zu\n", "GtkExpanderStyle", sizeof(GtkExpanderStyle), alignof(GtkExpanderStyle));
    printf("%s;%zu;%zu\n", "GtkFileChooserAction", sizeof(GtkFileChooserAction), alignof(GtkFileChooserAction));
    printf("%s;%zu;%zu\n", "GtkFileChooserButton", sizeof(GtkFileChooserButton), alignof(GtkFileChooserButton));
    printf("%s;%zu;%zu\n", "GtkFileChooserButtonClass", sizeof(GtkFileChooserButtonClass), alignof(GtkFileChooserButtonClass));
    printf("%s;%zu;%zu\n", "GtkFileChooserConfirmation", sizeof(GtkFileChooserConfirmation), alignof(GtkFileChooserConfirmation));
    printf("%s;%zu;%zu\n", "GtkFileChooserDialog", sizeof(GtkFileChooserDialog), alignof(GtkFileChooserDialog));
    printf("%s;%zu;%zu\n", "GtkFileChooserDialogClass", sizeof(GtkFileChooserDialogClass), alignof(GtkFileChooserDialogClass));
    printf("%s;%zu;%zu\n", "GtkFileChooserError", sizeof(GtkFileChooserError), alignof(GtkFileChooserError));
    printf("%s;%zu;%zu\n", "GtkFileChooserNativeClass", sizeof(GtkFileChooserNativeClass), alignof(GtkFileChooserNativeClass));
    printf("%s;%zu;%zu\n", "GtkFileChooserWidget", sizeof(GtkFileChooserWidget), alignof(GtkFileChooserWidget));
    printf("%s;%zu;%zu\n", "GtkFileChooserWidgetAccessible", sizeof(GtkFileChooserWidgetAccessible), alignof(GtkFileChooserWidgetAccessible));
    printf("%s;%zu;%zu\n", "GtkFileChooserWidgetAccessibleClass", sizeof(GtkFileChooserWidgetAccessibleClass), alignof(GtkFileChooserWidgetAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkFileChooserWidgetClass", sizeof(GtkFileChooserWidgetClass), alignof(GtkFileChooserWidgetClass));
    printf("%s;%zu;%zu\n", "GtkFileFilterFlags", sizeof(GtkFileFilterFlags), alignof(GtkFileFilterFlags));
    printf("%s;%zu;%zu\n", "GtkFileFilterInfo", sizeof(GtkFileFilterInfo), alignof(GtkFileFilterInfo));
    printf("%s;%zu;%zu\n", "GtkFixed", sizeof(GtkFixed), alignof(GtkFixed));
    printf("%s;%zu;%zu\n", "GtkFixedChild", sizeof(GtkFixedChild), alignof(GtkFixedChild));
    printf("%s;%zu;%zu\n", "GtkFixedClass", sizeof(GtkFixedClass), alignof(GtkFixedClass));
    printf("%s;%zu;%zu\n", "GtkFlowBox", sizeof(GtkFlowBox), alignof(GtkFlowBox));
    printf("%s;%zu;%zu\n", "GtkFlowBoxAccessible", sizeof(GtkFlowBoxAccessible), alignof(GtkFlowBoxAccessible));
    printf("%s;%zu;%zu\n", "GtkFlowBoxAccessibleClass", sizeof(GtkFlowBoxAccessibleClass), alignof(GtkFlowBoxAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkFlowBoxChild", sizeof(GtkFlowBoxChild), alignof(GtkFlowBoxChild));
    printf("%s;%zu;%zu\n", "GtkFlowBoxChildAccessible", sizeof(GtkFlowBoxChildAccessible), alignof(GtkFlowBoxChildAccessible));
    printf("%s;%zu;%zu\n", "GtkFlowBoxChildAccessibleClass", sizeof(GtkFlowBoxChildAccessibleClass), alignof(GtkFlowBoxChildAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkFlowBoxChildClass", sizeof(GtkFlowBoxChildClass), alignof(GtkFlowBoxChildClass));
    printf("%s;%zu;%zu\n", "GtkFlowBoxClass", sizeof(GtkFlowBoxClass), alignof(GtkFlowBoxClass));
    printf("%s;%zu;%zu\n", "GtkFontButton", sizeof(GtkFontButton), alignof(GtkFontButton));
    printf("%s;%zu;%zu\n", "GtkFontButtonClass", sizeof(GtkFontButtonClass), alignof(GtkFontButtonClass));
    printf("%s;%zu;%zu\n", "GtkFontChooserDialog", sizeof(GtkFontChooserDialog), alignof(GtkFontChooserDialog));
    printf("%s;%zu;%zu\n", "GtkFontChooserDialogClass", sizeof(GtkFontChooserDialogClass), alignof(GtkFontChooserDialogClass));
    printf("%s;%zu;%zu\n", "GtkFontChooserIface", sizeof(GtkFontChooserIface), alignof(GtkFontChooserIface));
    printf("%s;%zu;%zu\n", "GtkFontChooserLevel", sizeof(GtkFontChooserLevel), alignof(GtkFontChooserLevel));
    printf("%s;%zu;%zu\n", "GtkFontChooserWidget", sizeof(GtkFontChooserWidget), alignof(GtkFontChooserWidget));
    printf("%s;%zu;%zu\n", "GtkFontChooserWidgetClass", sizeof(GtkFontChooserWidgetClass), alignof(GtkFontChooserWidgetClass));
    printf("%s;%zu;%zu\n", "GtkFontSelection", sizeof(GtkFontSelection), alignof(GtkFontSelection));
    printf("%s;%zu;%zu\n", "GtkFontSelectionClass", sizeof(GtkFontSelectionClass), alignof(GtkFontSelectionClass));
    printf("%s;%zu;%zu\n", "GtkFontSelectionDialog", sizeof(GtkFontSelectionDialog), alignof(GtkFontSelectionDialog));
    printf("%s;%zu;%zu\n", "GtkFontSelectionDialogClass", sizeof(GtkFontSelectionDialogClass), alignof(GtkFontSelectionDialogClass));
    printf("%s;%zu;%zu\n", "GtkFrame", sizeof(GtkFrame), alignof(GtkFrame));
    printf("%s;%zu;%zu\n", "GtkFrameAccessible", sizeof(GtkFrameAccessible), alignof(GtkFrameAccessible));
    printf("%s;%zu;%zu\n", "GtkFrameAccessibleClass", sizeof(GtkFrameAccessibleClass), alignof(GtkFrameAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkFrameClass", sizeof(GtkFrameClass), alignof(GtkFrameClass));
    printf("%s;%zu;%zu\n", "GtkGLArea", sizeof(GtkGLArea), alignof(GtkGLArea));
    printf("%s;%zu;%zu\n", "GtkGLAreaClass", sizeof(GtkGLAreaClass), alignof(GtkGLAreaClass));
    printf("%s;%zu;%zu\n", "GtkGrid", sizeof(GtkGrid), alignof(GtkGrid));
    printf("%s;%zu;%zu\n", "GtkGridClass", sizeof(GtkGridClass), alignof(GtkGridClass));
    printf("%s;%zu;%zu\n", "GtkHBox", sizeof(GtkHBox), alignof(GtkHBox));
    printf("%s;%zu;%zu\n", "GtkHBoxClass", sizeof(GtkHBoxClass), alignof(GtkHBoxClass));
    printf("%s;%zu;%zu\n", "GtkHButtonBox", sizeof(GtkHButtonBox), alignof(GtkHButtonBox));
    printf("%s;%zu;%zu\n", "GtkHButtonBoxClass", sizeof(GtkHButtonBoxClass), alignof(GtkHButtonBoxClass));
    printf("%s;%zu;%zu\n", "GtkHPaned", sizeof(GtkHPaned), alignof(GtkHPaned));
    printf("%s;%zu;%zu\n", "GtkHPanedClass", sizeof(GtkHPanedClass), alignof(GtkHPanedClass));
    printf("%s;%zu;%zu\n", "GtkHSV", sizeof(GtkHSV), alignof(GtkHSV));
    printf("%s;%zu;%zu\n", "GtkHSVClass", sizeof(GtkHSVClass), alignof(GtkHSVClass));
    printf("%s;%zu;%zu\n", "GtkHScale", sizeof(GtkHScale), alignof(GtkHScale));
    printf("%s;%zu;%zu\n", "GtkHScaleClass", sizeof(GtkHScaleClass), alignof(GtkHScaleClass));
    printf("%s;%zu;%zu\n", "GtkHScrollbar", sizeof(GtkHScrollbar), alignof(GtkHScrollbar));
    printf("%s;%zu;%zu\n", "GtkHScrollbarClass", sizeof(GtkHScrollbarClass), alignof(GtkHScrollbarClass));
    printf("%s;%zu;%zu\n", "GtkHSeparator", sizeof(GtkHSeparator), alignof(GtkHSeparator));
    printf("%s;%zu;%zu\n", "GtkHSeparatorClass", sizeof(GtkHSeparatorClass), alignof(GtkHSeparatorClass));
    printf("%s;%zu;%zu\n", "GtkHandleBox", sizeof(GtkHandleBox), alignof(GtkHandleBox));
    printf("%s;%zu;%zu\n", "GtkHandleBoxClass", sizeof(GtkHandleBoxClass), alignof(GtkHandleBoxClass));
    printf("%s;%zu;%zu\n", "GtkHeaderBar", sizeof(GtkHeaderBar), alignof(GtkHeaderBar));
    printf("%s;%zu;%zu\n", "GtkHeaderBarAccessible", sizeof(GtkHeaderBarAccessible), alignof(GtkHeaderBarAccessible));
    printf("%s;%zu;%zu\n", "GtkHeaderBarAccessibleClass", sizeof(GtkHeaderBarAccessibleClass), alignof(GtkHeaderBarAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkHeaderBarClass", sizeof(GtkHeaderBarClass), alignof(GtkHeaderBarClass));
    printf("%s;%zu;%zu\n", "GtkIMContext", sizeof(GtkIMContext), alignof(GtkIMContext));
    printf("%s;%zu;%zu\n", "GtkIMContextClass", sizeof(GtkIMContextClass), alignof(GtkIMContextClass));
    printf("%s;%zu;%zu\n", "GtkIMContextInfo", sizeof(GtkIMContextInfo), alignof(GtkIMContextInfo));
    printf("%s;%zu;%zu\n", "GtkIMContextSimple", sizeof(GtkIMContextSimple), alignof(GtkIMContextSimple));
    printf("%s;%zu;%zu\n", "GtkIMContextSimpleClass", sizeof(GtkIMContextSimpleClass), alignof(GtkIMContextSimpleClass));
    printf("%s;%zu;%zu\n", "GtkIMMulticontext", sizeof(GtkIMMulticontext), alignof(GtkIMMulticontext));
    printf("%s;%zu;%zu\n", "GtkIMMulticontextClass", sizeof(GtkIMMulticontextClass), alignof(GtkIMMulticontextClass));
    printf("%s;%zu;%zu\n", "GtkIMPreeditStyle", sizeof(GtkIMPreeditStyle), alignof(GtkIMPreeditStyle));
    printf("%s;%zu;%zu\n", "GtkIMStatusStyle", sizeof(GtkIMStatusStyle), alignof(GtkIMStatusStyle));
    printf("%s;%zu;%zu\n", "GtkIconFactory", sizeof(GtkIconFactory), alignof(GtkIconFactory));
    printf("%s;%zu;%zu\n", "GtkIconFactoryClass", sizeof(GtkIconFactoryClass), alignof(GtkIconFactoryClass));
    printf("%s;%zu;%zu\n", "GtkIconLookupFlags", sizeof(GtkIconLookupFlags), alignof(GtkIconLookupFlags));
    printf("%s;%zu;%zu\n", "GtkIconSize", sizeof(GtkIconSize), alignof(GtkIconSize));
    printf("%s;%zu;%zu\n", "GtkIconTheme", sizeof(GtkIconTheme), alignof(GtkIconTheme));
    printf("%s;%zu;%zu\n", "GtkIconThemeClass", sizeof(GtkIconThemeClass), alignof(GtkIconThemeClass));
    printf("%s;%zu;%zu\n", "GtkIconThemeError", sizeof(GtkIconThemeError), alignof(GtkIconThemeError));
    printf("%s;%zu;%zu\n", "GtkIconView", sizeof(GtkIconView), alignof(GtkIconView));
    printf("%s;%zu;%zu\n", "GtkIconViewAccessible", sizeof(GtkIconViewAccessible), alignof(GtkIconViewAccessible));
    printf("%s;%zu;%zu\n", "GtkIconViewAccessibleClass", sizeof(GtkIconViewAccessibleClass), alignof(GtkIconViewAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkIconViewClass", sizeof(GtkIconViewClass), alignof(GtkIconViewClass));
    printf("%s;%zu;%zu\n", "GtkIconViewDropPosition", sizeof(GtkIconViewDropPosition), alignof(GtkIconViewDropPosition));
    printf("%s;%zu;%zu\n", "GtkImage", sizeof(GtkImage), alignof(GtkImage));
    printf("%s;%zu;%zu\n", "GtkImageAccessible", sizeof(GtkImageAccessible), alignof(GtkImageAccessible));
    printf("%s;%zu;%zu\n", "GtkImageAccessibleClass", sizeof(GtkImageAccessibleClass), alignof(GtkImageAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkImageCellAccessible", sizeof(GtkImageCellAccessible), alignof(GtkImageCellAccessible));
    printf("%s;%zu;%zu\n", "GtkImageCellAccessibleClass", sizeof(GtkImageCellAccessibleClass), alignof(GtkImageCellAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkImageClass", sizeof(GtkImageClass), alignof(GtkImageClass));
    printf("%s;%zu;%zu\n", "GtkImageMenuItem", sizeof(GtkImageMenuItem), alignof(GtkImageMenuItem));
    printf("%s;%zu;%zu\n", "GtkImageMenuItemClass", sizeof(GtkImageMenuItemClass), alignof(GtkImageMenuItemClass));
    printf("%s;%zu;%zu\n", "GtkImageType", sizeof(GtkImageType), alignof(GtkImageType));
    printf("%s;%zu;%zu\n", "GtkInfoBar", sizeof(GtkInfoBar), alignof(GtkInfoBar));
    printf("%s;%zu;%zu\n", "GtkInfoBarClass", sizeof(GtkInfoBarClass), alignof(GtkInfoBarClass));
    printf("%s;%zu;%zu\n", "GtkInputHints", sizeof(GtkInputHints), alignof(GtkInputHints));
    printf("%s;%zu;%zu\n", "GtkInputPurpose", sizeof(GtkInputPurpose), alignof(GtkInputPurpose));
    printf("%s;%zu;%zu\n", "GtkInvisible", sizeof(GtkInvisible), alignof(GtkInvisible));
    printf("%s;%zu;%zu\n", "GtkInvisibleClass", sizeof(GtkInvisibleClass), alignof(GtkInvisibleClass));
    printf("%s;%zu;%zu\n", "GtkJunctionSides", sizeof(GtkJunctionSides), alignof(GtkJunctionSides));
    printf("%s;%zu;%zu\n", "GtkJustification", sizeof(GtkJustification), alignof(GtkJustification));
    printf("%s;%zu;%zu\n", "GtkLabel", sizeof(GtkLabel), alignof(GtkLabel));
    printf("%s;%zu;%zu\n", "GtkLabelAccessible", sizeof(GtkLabelAccessible), alignof(GtkLabelAccessible));
    printf("%s;%zu;%zu\n", "GtkLabelAccessibleClass", sizeof(GtkLabelAccessibleClass), alignof(GtkLabelAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkLabelClass", sizeof(GtkLabelClass), alignof(GtkLabelClass));
    printf("%s;%zu;%zu\n", "GtkLayout", sizeof(GtkLayout), alignof(GtkLayout));
    printf("%s;%zu;%zu\n", "GtkLayoutClass", sizeof(GtkLayoutClass), alignof(GtkLayoutClass));
    printf("%s;%zu;%zu\n", "GtkLevelBar", sizeof(GtkLevelBar), alignof(GtkLevelBar));
    printf("%s;%zu;%zu\n", "GtkLevelBarAccessible", sizeof(GtkLevelBarAccessible), alignof(GtkLevelBarAccessible));
    printf("%s;%zu;%zu\n", "GtkLevelBarAccessibleClass", sizeof(GtkLevelBarAccessibleClass), alignof(GtkLevelBarAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkLevelBarClass", sizeof(GtkLevelBarClass), alignof(GtkLevelBarClass));
    printf("%s;%zu;%zu\n", "GtkLevelBarMode", sizeof(GtkLevelBarMode), alignof(GtkLevelBarMode));
    printf("%s;%zu;%zu\n", "GtkLicense", sizeof(GtkLicense), alignof(GtkLicense));
    printf("%s;%zu;%zu\n", "GtkLinkButton", sizeof(GtkLinkButton), alignof(GtkLinkButton));
    printf("%s;%zu;%zu\n", "GtkLinkButtonAccessible", sizeof(GtkLinkButtonAccessible), alignof(GtkLinkButtonAccessible));
    printf("%s;%zu;%zu\n", "GtkLinkButtonAccessibleClass", sizeof(GtkLinkButtonAccessibleClass), alignof(GtkLinkButtonAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkLinkButtonClass", sizeof(GtkLinkButtonClass), alignof(GtkLinkButtonClass));
    printf("%s;%zu;%zu\n", "GtkListBox", sizeof(GtkListBox), alignof(GtkListBox));
    printf("%s;%zu;%zu\n", "GtkListBoxAccessible", sizeof(GtkListBoxAccessible), alignof(GtkListBoxAccessible));
    printf("%s;%zu;%zu\n", "GtkListBoxAccessibleClass", sizeof(GtkListBoxAccessibleClass), alignof(GtkListBoxAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkListBoxClass", sizeof(GtkListBoxClass), alignof(GtkListBoxClass));
    printf("%s;%zu;%zu\n", "GtkListBoxRow", sizeof(GtkListBoxRow), alignof(GtkListBoxRow));
    printf("%s;%zu;%zu\n", "GtkListBoxRowAccessible", sizeof(GtkListBoxRowAccessible), alignof(GtkListBoxRowAccessible));
    printf("%s;%zu;%zu\n", "GtkListBoxRowAccessibleClass", sizeof(GtkListBoxRowAccessibleClass), alignof(GtkListBoxRowAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkListBoxRowClass", sizeof(GtkListBoxRowClass), alignof(GtkListBoxRowClass));
    printf("%s;%zu;%zu\n", "GtkListStore", sizeof(GtkListStore), alignof(GtkListStore));
    printf("%s;%zu;%zu\n", "GtkListStoreClass", sizeof(GtkListStoreClass), alignof(GtkListStoreClass));
    printf("%s;%zu;%zu\n", "GtkLockButton", sizeof(GtkLockButton), alignof(GtkLockButton));
    printf("%s;%zu;%zu\n", "GtkLockButtonAccessible", sizeof(GtkLockButtonAccessible), alignof(GtkLockButtonAccessible));
    printf("%s;%zu;%zu\n", "GtkLockButtonAccessibleClass", sizeof(GtkLockButtonAccessibleClass), alignof(GtkLockButtonAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkLockButtonClass", sizeof(GtkLockButtonClass), alignof(GtkLockButtonClass));
    printf("%s;%zu;%zu\n", "GtkMenu", sizeof(GtkMenu), alignof(GtkMenu));
    printf("%s;%zu;%zu\n", "GtkMenuAccessible", sizeof(GtkMenuAccessible), alignof(GtkMenuAccessible));
    printf("%s;%zu;%zu\n", "GtkMenuAccessibleClass", sizeof(GtkMenuAccessibleClass), alignof(GtkMenuAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkMenuBar", sizeof(GtkMenuBar), alignof(GtkMenuBar));
    printf("%s;%zu;%zu\n", "GtkMenuBarClass", sizeof(GtkMenuBarClass), alignof(GtkMenuBarClass));
    printf("%s;%zu;%zu\n", "GtkMenuButton", sizeof(GtkMenuButton), alignof(GtkMenuButton));
    printf("%s;%zu;%zu\n", "GtkMenuButtonAccessible", sizeof(GtkMenuButtonAccessible), alignof(GtkMenuButtonAccessible));
    printf("%s;%zu;%zu\n", "GtkMenuButtonAccessibleClass", sizeof(GtkMenuButtonAccessibleClass), alignof(GtkMenuButtonAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkMenuButtonClass", sizeof(GtkMenuButtonClass), alignof(GtkMenuButtonClass));
    printf("%s;%zu;%zu\n", "GtkMenuClass", sizeof(GtkMenuClass), alignof(GtkMenuClass));
    printf("%s;%zu;%zu\n", "GtkMenuDirectionType", sizeof(GtkMenuDirectionType), alignof(GtkMenuDirectionType));
    printf("%s;%zu;%zu\n", "GtkMenuItem", sizeof(GtkMenuItem), alignof(GtkMenuItem));
    printf("%s;%zu;%zu\n", "GtkMenuItemAccessible", sizeof(GtkMenuItemAccessible), alignof(GtkMenuItemAccessible));
    printf("%s;%zu;%zu\n", "GtkMenuItemAccessibleClass", sizeof(GtkMenuItemAccessibleClass), alignof(GtkMenuItemAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkMenuItemClass", sizeof(GtkMenuItemClass), alignof(GtkMenuItemClass));
    printf("%s;%zu;%zu\n", "GtkMenuShell", sizeof(GtkMenuShell), alignof(GtkMenuShell));
    printf("%s;%zu;%zu\n", "GtkMenuShellAccessible", sizeof(GtkMenuShellAccessible), alignof(GtkMenuShellAccessible));
    printf("%s;%zu;%zu\n", "GtkMenuShellAccessibleClass", sizeof(GtkMenuShellAccessibleClass), alignof(GtkMenuShellAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkMenuShellClass", sizeof(GtkMenuShellClass), alignof(GtkMenuShellClass));
    printf("%s;%zu;%zu\n", "GtkMenuToolButton", sizeof(GtkMenuToolButton), alignof(GtkMenuToolButton));
    printf("%s;%zu;%zu\n", "GtkMenuToolButtonClass", sizeof(GtkMenuToolButtonClass), alignof(GtkMenuToolButtonClass));
    printf("%s;%zu;%zu\n", "GtkMessageDialog", sizeof(GtkMessageDialog), alignof(GtkMessageDialog));
    printf("%s;%zu;%zu\n", "GtkMessageDialogClass", sizeof(GtkMessageDialogClass), alignof(GtkMessageDialogClass));
    printf("%s;%zu;%zu\n", "GtkMessageType", sizeof(GtkMessageType), alignof(GtkMessageType));
    printf("%s;%zu;%zu\n", "GtkMisc", sizeof(GtkMisc), alignof(GtkMisc));
    printf("%s;%zu;%zu\n", "GtkMiscClass", sizeof(GtkMiscClass), alignof(GtkMiscClass));
    printf("%s;%zu;%zu\n", "GtkMountOperation", sizeof(GtkMountOperation), alignof(GtkMountOperation));
    printf("%s;%zu;%zu\n", "GtkMountOperationClass", sizeof(GtkMountOperationClass), alignof(GtkMountOperationClass));
    printf("%s;%zu;%zu\n", "GtkMovementStep", sizeof(GtkMovementStep), alignof(GtkMovementStep));
    printf("%s;%zu;%zu\n", "GtkNativeDialog", sizeof(GtkNativeDialog), alignof(GtkNativeDialog));
    printf("%s;%zu;%zu\n", "GtkNativeDialogClass", sizeof(GtkNativeDialogClass), alignof(GtkNativeDialogClass));
    printf("%s;%zu;%zu\n", "GtkNotebook", sizeof(GtkNotebook), alignof(GtkNotebook));
    printf("%s;%zu;%zu\n", "GtkNotebookAccessible", sizeof(GtkNotebookAccessible), alignof(GtkNotebookAccessible));
    printf("%s;%zu;%zu\n", "GtkNotebookAccessibleClass", sizeof(GtkNotebookAccessibleClass), alignof(GtkNotebookAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkNotebookClass", sizeof(GtkNotebookClass), alignof(GtkNotebookClass));
    printf("%s;%zu;%zu\n", "GtkNotebookPageAccessible", sizeof(GtkNotebookPageAccessible), alignof(GtkNotebookPageAccessible));
    printf("%s;%zu;%zu\n", "GtkNotebookPageAccessibleClass", sizeof(GtkNotebookPageAccessibleClass), alignof(GtkNotebookPageAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkNotebookTab", sizeof(GtkNotebookTab), alignof(GtkNotebookTab));
    printf("%s;%zu;%zu\n", "GtkNumberUpLayout", sizeof(GtkNumberUpLayout), alignof(GtkNumberUpLayout));
    printf("%s;%zu;%zu\n", "GtkNumerableIcon", sizeof(GtkNumerableIcon), alignof(GtkNumerableIcon));
    printf("%s;%zu;%zu\n", "GtkNumerableIconClass", sizeof(GtkNumerableIconClass), alignof(GtkNumerableIconClass));
    printf("%s;%zu;%zu\n", "GtkOffscreenWindow", sizeof(GtkOffscreenWindow), alignof(GtkOffscreenWindow));
    printf("%s;%zu;%zu\n", "GtkOffscreenWindowClass", sizeof(GtkOffscreenWindowClass), alignof(GtkOffscreenWindowClass));
    printf("%s;%zu;%zu\n", "GtkOrientableIface", sizeof(GtkOrientableIface), alignof(GtkOrientableIface));
    printf("%s;%zu;%zu\n", "GtkOrientation", sizeof(GtkOrientation), alignof(GtkOrientation));
    printf("%s;%zu;%zu\n", "GtkOverlay", sizeof(GtkOverlay), alignof(GtkOverlay));
    printf("%s;%zu;%zu\n", "GtkOverlayClass", sizeof(GtkOverlayClass), alignof(GtkOverlayClass));
    printf("%s;%zu;%zu\n", "GtkPackDirection", sizeof(GtkPackDirection), alignof(GtkPackDirection));
    printf("%s;%zu;%zu\n", "GtkPackType", sizeof(GtkPackType), alignof(GtkPackType));
    printf("%s;%zu;%zu\n", "GtkPadActionEntry", sizeof(GtkPadActionEntry), alignof(GtkPadActionEntry));
    printf("%s;%zu;%zu\n", "GtkPadActionType", sizeof(GtkPadActionType), alignof(GtkPadActionType));
    printf("%s;%zu;%zu\n", "GtkPageOrientation", sizeof(GtkPageOrientation), alignof(GtkPageOrientation));
    printf("%s;%zu;%zu\n", "GtkPageRange", sizeof(GtkPageRange), alignof(GtkPageRange));
    printf("%s;%zu;%zu\n", "GtkPageSet", sizeof(GtkPageSet), alignof(GtkPageSet));
    printf("%s;%zu;%zu\n", "GtkPanDirection", sizeof(GtkPanDirection), alignof(GtkPanDirection));
    printf("%s;%zu;%zu\n", "GtkPaned", sizeof(GtkPaned), alignof(GtkPaned));
    printf("%s;%zu;%zu\n", "GtkPanedAccessible", sizeof(GtkPanedAccessible), alignof(GtkPanedAccessible));
    printf("%s;%zu;%zu\n", "GtkPanedAccessibleClass", sizeof(GtkPanedAccessibleClass), alignof(GtkPanedAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkPanedClass", sizeof(GtkPanedClass), alignof(GtkPanedClass));
    printf("%s;%zu;%zu\n", "GtkPathPriorityType", sizeof(GtkPathPriorityType), alignof(GtkPathPriorityType));
    printf("%s;%zu;%zu\n", "GtkPathType", sizeof(GtkPathType), alignof(GtkPathType));
    printf("%s;%zu;%zu\n", "GtkPlacesOpenFlags", sizeof(GtkPlacesOpenFlags), alignof(GtkPlacesOpenFlags));
    printf("%s;%zu;%zu\n", "GtkPlug", sizeof(GtkPlug), alignof(GtkPlug));
    printf("%s;%zu;%zu\n", "GtkPlugAccessible", sizeof(GtkPlugAccessible), alignof(GtkPlugAccessible));
    printf("%s;%zu;%zu\n", "GtkPlugAccessibleClass", sizeof(GtkPlugAccessibleClass), alignof(GtkPlugAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkPlugClass", sizeof(GtkPlugClass), alignof(GtkPlugClass));
    printf("%s;%zu;%zu\n", "GtkPolicyType", sizeof(GtkPolicyType), alignof(GtkPolicyType));
    printf("%s;%zu;%zu\n", "GtkPopover", sizeof(GtkPopover), alignof(GtkPopover));
    printf("%s;%zu;%zu\n", "GtkPopoverAccessible", sizeof(GtkPopoverAccessible), alignof(GtkPopoverAccessible));
    printf("%s;%zu;%zu\n", "GtkPopoverAccessibleClass", sizeof(GtkPopoverAccessibleClass), alignof(GtkPopoverAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkPopoverClass", sizeof(GtkPopoverClass), alignof(GtkPopoverClass));
    printf("%s;%zu;%zu\n", "GtkPopoverConstraint", sizeof(GtkPopoverConstraint), alignof(GtkPopoverConstraint));
    printf("%s;%zu;%zu\n", "GtkPopoverMenuClass", sizeof(GtkPopoverMenuClass), alignof(GtkPopoverMenuClass));
    printf("%s;%zu;%zu\n", "GtkPositionType", sizeof(GtkPositionType), alignof(GtkPositionType));
    printf("%s;%zu;%zu\n", "GtkPrintDuplex", sizeof(GtkPrintDuplex), alignof(GtkPrintDuplex));
    printf("%s;%zu;%zu\n", "GtkPrintError", sizeof(GtkPrintError), alignof(GtkPrintError));
    printf("%s;%zu;%zu\n", "GtkPrintOperation", sizeof(GtkPrintOperation), alignof(GtkPrintOperation));
    printf("%s;%zu;%zu\n", "GtkPrintOperationAction", sizeof(GtkPrintOperationAction), alignof(GtkPrintOperationAction));
    printf("%s;%zu;%zu\n", "GtkPrintOperationClass", sizeof(GtkPrintOperationClass), alignof(GtkPrintOperationClass));
    printf("%s;%zu;%zu\n", "GtkPrintOperationPreviewIface", sizeof(GtkPrintOperationPreviewIface), alignof(GtkPrintOperationPreviewIface));
    printf("%s;%zu;%zu\n", "GtkPrintOperationResult", sizeof(GtkPrintOperationResult), alignof(GtkPrintOperationResult));
    printf("%s;%zu;%zu\n", "GtkPrintPages", sizeof(GtkPrintPages), alignof(GtkPrintPages));
    printf("%s;%zu;%zu\n", "GtkPrintQuality", sizeof(GtkPrintQuality), alignof(GtkPrintQuality));
    printf("%s;%zu;%zu\n", "GtkPrintStatus", sizeof(GtkPrintStatus), alignof(GtkPrintStatus));
    printf("%s;%zu;%zu\n", "GtkProgressBar", sizeof(GtkProgressBar), alignof(GtkProgressBar));
    printf("%s;%zu;%zu\n", "GtkProgressBarAccessible", sizeof(GtkProgressBarAccessible), alignof(GtkProgressBarAccessible));
    printf("%s;%zu;%zu\n", "GtkProgressBarAccessibleClass", sizeof(GtkProgressBarAccessibleClass), alignof(GtkProgressBarAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkProgressBarClass", sizeof(GtkProgressBarClass), alignof(GtkProgressBarClass));
    printf("%s;%zu;%zu\n", "GtkPropagationPhase", sizeof(GtkPropagationPhase), alignof(GtkPropagationPhase));
    printf("%s;%zu;%zu\n", "GtkRadioAction", sizeof(GtkRadioAction), alignof(GtkRadioAction));
    printf("%s;%zu;%zu\n", "GtkRadioActionClass", sizeof(GtkRadioActionClass), alignof(GtkRadioActionClass));
    printf("%s;%zu;%zu\n", "GtkRadioActionEntry", sizeof(GtkRadioActionEntry), alignof(GtkRadioActionEntry));
    printf("%s;%zu;%zu\n", "GtkRadioButton", sizeof(GtkRadioButton), alignof(GtkRadioButton));
    printf("%s;%zu;%zu\n", "GtkRadioButtonAccessible", sizeof(GtkRadioButtonAccessible), alignof(GtkRadioButtonAccessible));
    printf("%s;%zu;%zu\n", "GtkRadioButtonAccessibleClass", sizeof(GtkRadioButtonAccessibleClass), alignof(GtkRadioButtonAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkRadioButtonClass", sizeof(GtkRadioButtonClass), alignof(GtkRadioButtonClass));
    printf("%s;%zu;%zu\n", "GtkRadioMenuItem", sizeof(GtkRadioMenuItem), alignof(GtkRadioMenuItem));
    printf("%s;%zu;%zu\n", "GtkRadioMenuItemAccessible", sizeof(GtkRadioMenuItemAccessible), alignof(GtkRadioMenuItemAccessible));
    printf("%s;%zu;%zu\n", "GtkRadioMenuItemAccessibleClass", sizeof(GtkRadioMenuItemAccessibleClass), alignof(GtkRadioMenuItemAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkRadioMenuItemClass", sizeof(GtkRadioMenuItemClass), alignof(GtkRadioMenuItemClass));
    printf("%s;%zu;%zu\n", "GtkRadioToolButton", sizeof(GtkRadioToolButton), alignof(GtkRadioToolButton));
    printf("%s;%zu;%zu\n", "GtkRadioToolButtonClass", sizeof(GtkRadioToolButtonClass), alignof(GtkRadioToolButtonClass));
    printf("%s;%zu;%zu\n", "GtkRange", sizeof(GtkRange), alignof(GtkRange));
    printf("%s;%zu;%zu\n", "GtkRangeAccessible", sizeof(GtkRangeAccessible), alignof(GtkRangeAccessible));
    printf("%s;%zu;%zu\n", "GtkRangeAccessibleClass", sizeof(GtkRangeAccessibleClass), alignof(GtkRangeAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkRangeClass", sizeof(GtkRangeClass), alignof(GtkRangeClass));
    printf("%s;%zu;%zu\n", "GtkRcFlags", sizeof(GtkRcFlags), alignof(GtkRcFlags));
    printf("%s;%zu;%zu\n", "GtkRcProperty", sizeof(GtkRcProperty), alignof(GtkRcProperty));
    printf("%s;%zu;%zu\n", "GtkRcStyle", sizeof(GtkRcStyle), alignof(GtkRcStyle));
    printf("%s;%zu;%zu\n", "GtkRcStyleClass", sizeof(GtkRcStyleClass), alignof(GtkRcStyleClass));
    printf("%s;%zu;%zu\n", "GtkRcTokenType", sizeof(GtkRcTokenType), alignof(GtkRcTokenType));
    printf("%s;%zu;%zu\n", "GtkRecentAction", sizeof(GtkRecentAction), alignof(GtkRecentAction));
    printf("%s;%zu;%zu\n", "GtkRecentActionClass", sizeof(GtkRecentActionClass), alignof(GtkRecentActionClass));
    printf("%s;%zu;%zu\n", "GtkRecentChooserDialog", sizeof(GtkRecentChooserDialog), alignof(GtkRecentChooserDialog));
    printf("%s;%zu;%zu\n", "GtkRecentChooserDialogClass", sizeof(GtkRecentChooserDialogClass), alignof(GtkRecentChooserDialogClass));
    printf("%s;%zu;%zu\n", "GtkRecentChooserError", sizeof(GtkRecentChooserError), alignof(GtkRecentChooserError));
    printf("%s;%zu;%zu\n", "GtkRecentChooserIface", sizeof(GtkRecentChooserIface), alignof(GtkRecentChooserIface));
    printf("%s;%zu;%zu\n", "GtkRecentChooserMenu", sizeof(GtkRecentChooserMenu), alignof(GtkRecentChooserMenu));
    printf("%s;%zu;%zu\n", "GtkRecentChooserMenuClass", sizeof(GtkRecentChooserMenuClass), alignof(GtkRecentChooserMenuClass));
    printf("%s;%zu;%zu\n", "GtkRecentChooserWidget", sizeof(GtkRecentChooserWidget), alignof(GtkRecentChooserWidget));
    printf("%s;%zu;%zu\n", "GtkRecentChooserWidgetClass", sizeof(GtkRecentChooserWidgetClass), alignof(GtkRecentChooserWidgetClass));
    printf("%s;%zu;%zu\n", "GtkRecentData", sizeof(GtkRecentData), alignof(GtkRecentData));
    printf("%s;%zu;%zu\n", "GtkRecentFilterFlags", sizeof(GtkRecentFilterFlags), alignof(GtkRecentFilterFlags));
    printf("%s;%zu;%zu\n", "GtkRecentFilterInfo", sizeof(GtkRecentFilterInfo), alignof(GtkRecentFilterInfo));
    printf("%s;%zu;%zu\n", "GtkRecentManager", sizeof(GtkRecentManager), alignof(GtkRecentManager));
    printf("%s;%zu;%zu\n", "GtkRecentManagerClass", sizeof(GtkRecentManagerClass), alignof(GtkRecentManagerClass));
    printf("%s;%zu;%zu\n", "GtkRecentManagerError", sizeof(GtkRecentManagerError), alignof(GtkRecentManagerError));
    printf("%s;%zu;%zu\n", "GtkRecentSortType", sizeof(GtkRecentSortType), alignof(GtkRecentSortType));
    printf("%s;%zu;%zu\n", "GtkRegionFlags", sizeof(GtkRegionFlags), alignof(GtkRegionFlags));
    printf("%s;%zu;%zu\n", "GtkReliefStyle", sizeof(GtkReliefStyle), alignof(GtkReliefStyle));
    printf("%s;%zu;%zu\n", "GtkRendererCellAccessible", sizeof(GtkRendererCellAccessible), alignof(GtkRendererCellAccessible));
    printf("%s;%zu;%zu\n", "GtkRendererCellAccessibleClass", sizeof(GtkRendererCellAccessibleClass), alignof(GtkRendererCellAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkRequestedSize", sizeof(GtkRequestedSize), alignof(GtkRequestedSize));
    printf("%s;%zu;%zu\n", "GtkRequisition", sizeof(GtkRequisition), alignof(GtkRequisition));
    printf("%s;%zu;%zu\n", "GtkResizeMode", sizeof(GtkResizeMode), alignof(GtkResizeMode));
    printf("%s;%zu;%zu\n", "GtkResponseType", sizeof(GtkResponseType), alignof(GtkResponseType));
    printf("%s;%zu;%zu\n", "GtkRevealer", sizeof(GtkRevealer), alignof(GtkRevealer));
    printf("%s;%zu;%zu\n", "GtkRevealerClass", sizeof(GtkRevealerClass), alignof(GtkRevealerClass));
    printf("%s;%zu;%zu\n", "GtkRevealerTransitionType", sizeof(GtkRevealerTransitionType), alignof(GtkRevealerTransitionType));
    printf("%s;%zu;%zu\n", "GtkScale", sizeof(GtkScale), alignof(GtkScale));
    printf("%s;%zu;%zu\n", "GtkScaleAccessible", sizeof(GtkScaleAccessible), alignof(GtkScaleAccessible));
    printf("%s;%zu;%zu\n", "GtkScaleAccessibleClass", sizeof(GtkScaleAccessibleClass), alignof(GtkScaleAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkScaleButton", sizeof(GtkScaleButton), alignof(GtkScaleButton));
    printf("%s;%zu;%zu\n", "GtkScaleButtonAccessible", sizeof(GtkScaleButtonAccessible), alignof(GtkScaleButtonAccessible));
    printf("%s;%zu;%zu\n", "GtkScaleButtonAccessibleClass", sizeof(GtkScaleButtonAccessibleClass), alignof(GtkScaleButtonAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkScaleButtonClass", sizeof(GtkScaleButtonClass), alignof(GtkScaleButtonClass));
    printf("%s;%zu;%zu\n", "GtkScaleClass", sizeof(GtkScaleClass), alignof(GtkScaleClass));
    printf("%s;%zu;%zu\n", "GtkScrollStep", sizeof(GtkScrollStep), alignof(GtkScrollStep));
    printf("%s;%zu;%zu\n", "GtkScrollType", sizeof(GtkScrollType), alignof(GtkScrollType));
    printf("%s;%zu;%zu\n", "GtkScrollableInterface", sizeof(GtkScrollableInterface), alignof(GtkScrollableInterface));
    printf("%s;%zu;%zu\n", "GtkScrollablePolicy", sizeof(GtkScrollablePolicy), alignof(GtkScrollablePolicy));
    printf("%s;%zu;%zu\n", "GtkScrollbar", sizeof(GtkScrollbar), alignof(GtkScrollbar));
    printf("%s;%zu;%zu\n", "GtkScrollbarClass", sizeof(GtkScrollbarClass), alignof(GtkScrollbarClass));
    printf("%s;%zu;%zu\n", "GtkScrolledWindow", sizeof(GtkScrolledWindow), alignof(GtkScrolledWindow));
    printf("%s;%zu;%zu\n", "GtkScrolledWindowAccessible", sizeof(GtkScrolledWindowAccessible), alignof(GtkScrolledWindowAccessible));
    printf("%s;%zu;%zu\n", "GtkScrolledWindowAccessibleClass", sizeof(GtkScrolledWindowAccessibleClass), alignof(GtkScrolledWindowAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkScrolledWindowClass", sizeof(GtkScrolledWindowClass), alignof(GtkScrolledWindowClass));
    printf("%s;%zu;%zu\n", "GtkSearchBar", sizeof(GtkSearchBar), alignof(GtkSearchBar));
    printf("%s;%zu;%zu\n", "GtkSearchBarClass", sizeof(GtkSearchBarClass), alignof(GtkSearchBarClass));
    printf("%s;%zu;%zu\n", "GtkSearchEntry", sizeof(GtkSearchEntry), alignof(GtkSearchEntry));
    printf("%s;%zu;%zu\n", "GtkSearchEntryClass", sizeof(GtkSearchEntryClass), alignof(GtkSearchEntryClass));
    printf("%s;%zu;%zu\n", "GtkSelectionMode", sizeof(GtkSelectionMode), alignof(GtkSelectionMode));
    printf("%s;%zu;%zu\n", "GtkSensitivityType", sizeof(GtkSensitivityType), alignof(GtkSensitivityType));
    printf("%s;%zu;%zu\n", "GtkSeparator", sizeof(GtkSeparator), alignof(GtkSeparator));
    printf("%s;%zu;%zu\n", "GtkSeparatorClass", sizeof(GtkSeparatorClass), alignof(GtkSeparatorClass));
    printf("%s;%zu;%zu\n", "GtkSeparatorMenuItem", sizeof(GtkSeparatorMenuItem), alignof(GtkSeparatorMenuItem));
    printf("%s;%zu;%zu\n", "GtkSeparatorMenuItemClass", sizeof(GtkSeparatorMenuItemClass), alignof(GtkSeparatorMenuItemClass));
    printf("%s;%zu;%zu\n", "GtkSeparatorToolItem", sizeof(GtkSeparatorToolItem), alignof(GtkSeparatorToolItem));
    printf("%s;%zu;%zu\n", "GtkSeparatorToolItemClass", sizeof(GtkSeparatorToolItemClass), alignof(GtkSeparatorToolItemClass));
    printf("%s;%zu;%zu\n", "GtkSettings", sizeof(GtkSettings), alignof(GtkSettings));
    printf("%s;%zu;%zu\n", "GtkSettingsClass", sizeof(GtkSettingsClass), alignof(GtkSettingsClass));
    printf("%s;%zu;%zu\n", "GtkSettingsValue", sizeof(GtkSettingsValue), alignof(GtkSettingsValue));
    printf("%s;%zu;%zu\n", "GtkShadowType", sizeof(GtkShadowType), alignof(GtkShadowType));
    printf("%s;%zu;%zu\n", "GtkShortcutType", sizeof(GtkShortcutType), alignof(GtkShortcutType));
    printf("%s;%zu;%zu\n", "GtkShortcutsWindow", sizeof(GtkShortcutsWindow), alignof(GtkShortcutsWindow));
    printf("%s;%zu;%zu\n", "GtkShortcutsWindowClass", sizeof(GtkShortcutsWindowClass), alignof(GtkShortcutsWindowClass));
    printf("%s;%zu;%zu\n", "GtkSizeGroup", sizeof(GtkSizeGroup), alignof(GtkSizeGroup));
    printf("%s;%zu;%zu\n", "GtkSizeGroupClass", sizeof(GtkSizeGroupClass), alignof(GtkSizeGroupClass));
    printf("%s;%zu;%zu\n", "GtkSizeGroupMode", sizeof(GtkSizeGroupMode), alignof(GtkSizeGroupMode));
    printf("%s;%zu;%zu\n", "GtkSizeRequestMode", sizeof(GtkSizeRequestMode), alignof(GtkSizeRequestMode));
    printf("%s;%zu;%zu\n", "GtkSocket", sizeof(GtkSocket), alignof(GtkSocket));
    printf("%s;%zu;%zu\n", "GtkSocketAccessible", sizeof(GtkSocketAccessible), alignof(GtkSocketAccessible));
    printf("%s;%zu;%zu\n", "GtkSocketAccessibleClass", sizeof(GtkSocketAccessibleClass), alignof(GtkSocketAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkSocketClass", sizeof(GtkSocketClass), alignof(GtkSocketClass));
    printf("%s;%zu;%zu\n", "GtkSortType", sizeof(GtkSortType), alignof(GtkSortType));
    printf("%s;%zu;%zu\n", "GtkSpinButton", sizeof(GtkSpinButton), alignof(GtkSpinButton));
    printf("%s;%zu;%zu\n", "GtkSpinButtonAccessible", sizeof(GtkSpinButtonAccessible), alignof(GtkSpinButtonAccessible));
    printf("%s;%zu;%zu\n", "GtkSpinButtonAccessibleClass", sizeof(GtkSpinButtonAccessibleClass), alignof(GtkSpinButtonAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkSpinButtonClass", sizeof(GtkSpinButtonClass), alignof(GtkSpinButtonClass));
    printf("%s;%zu;%zu\n", "GtkSpinButtonUpdatePolicy", sizeof(GtkSpinButtonUpdatePolicy), alignof(GtkSpinButtonUpdatePolicy));
    printf("%s;%zu;%zu\n", "GtkSpinType", sizeof(GtkSpinType), alignof(GtkSpinType));
    printf("%s;%zu;%zu\n", "GtkSpinner", sizeof(GtkSpinner), alignof(GtkSpinner));
    printf("%s;%zu;%zu\n", "GtkSpinnerAccessible", sizeof(GtkSpinnerAccessible), alignof(GtkSpinnerAccessible));
    printf("%s;%zu;%zu\n", "GtkSpinnerAccessibleClass", sizeof(GtkSpinnerAccessibleClass), alignof(GtkSpinnerAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkSpinnerClass", sizeof(GtkSpinnerClass), alignof(GtkSpinnerClass));
    printf("%s;%zu;%zu\n", "GtkStack", sizeof(GtkStack), alignof(GtkStack));
    printf("%s;%zu;%zu\n", "GtkStackAccessible", sizeof(GtkStackAccessible), alignof(GtkStackAccessible));
    printf("%s;%zu;%zu\n", "GtkStackAccessibleClass", sizeof(GtkStackAccessibleClass), alignof(GtkStackAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkStackClass", sizeof(GtkStackClass), alignof(GtkStackClass));
    printf("%s;%zu;%zu\n", "GtkStackSidebar", sizeof(GtkStackSidebar), alignof(GtkStackSidebar));
    printf("%s;%zu;%zu\n", "GtkStackSidebarClass", sizeof(GtkStackSidebarClass), alignof(GtkStackSidebarClass));
    printf("%s;%zu;%zu\n", "GtkStackSwitcher", sizeof(GtkStackSwitcher), alignof(GtkStackSwitcher));
    printf("%s;%zu;%zu\n", "GtkStackSwitcherClass", sizeof(GtkStackSwitcherClass), alignof(GtkStackSwitcherClass));
    printf("%s;%zu;%zu\n", "GtkStackTransitionType", sizeof(GtkStackTransitionType), alignof(GtkStackTransitionType));
    printf("%s;%zu;%zu\n", "GtkStateFlags", sizeof(GtkStateFlags), alignof(GtkStateFlags));
    printf("%s;%zu;%zu\n", "GtkStateType", sizeof(GtkStateType), alignof(GtkStateType));
    printf("%s;%zu;%zu\n", "GtkStatusIcon", sizeof(GtkStatusIcon), alignof(GtkStatusIcon));
    printf("%s;%zu;%zu\n", "GtkStatusIconClass", sizeof(GtkStatusIconClass), alignof(GtkStatusIconClass));
    printf("%s;%zu;%zu\n", "GtkStatusbar", sizeof(GtkStatusbar), alignof(GtkStatusbar));
    printf("%s;%zu;%zu\n", "GtkStatusbarAccessible", sizeof(GtkStatusbarAccessible), alignof(GtkStatusbarAccessible));
    printf("%s;%zu;%zu\n", "GtkStatusbarAccessibleClass", sizeof(GtkStatusbarAccessibleClass), alignof(GtkStatusbarAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkStatusbarClass", sizeof(GtkStatusbarClass), alignof(GtkStatusbarClass));
    printf("%s;%zu;%zu\n", "GtkStock", sizeof(GtkStock), alignof(GtkStock));
    printf("%s;%zu;%zu\n", "GtkStockItem", sizeof(GtkStockItem), alignof(GtkStockItem));
    printf("%s;%zu;%zu\n", "GtkStyleClass", sizeof(GtkStyleClass), alignof(GtkStyleClass));
    printf("%s;%zu;%zu\n", "GtkStyleContext", sizeof(GtkStyleContext), alignof(GtkStyleContext));
    printf("%s;%zu;%zu\n", "GtkStyleContextClass", sizeof(GtkStyleContextClass), alignof(GtkStyleContextClass));
    printf("%s;%zu;%zu\n", "GtkStyleContextPrintFlags", sizeof(GtkStyleContextPrintFlags), alignof(GtkStyleContextPrintFlags));
    printf("%s;%zu;%zu\n", "GtkStyleProperties", sizeof(GtkStyleProperties), alignof(GtkStyleProperties));
    printf("%s;%zu;%zu\n", "GtkStylePropertiesClass", sizeof(GtkStylePropertiesClass), alignof(GtkStylePropertiesClass));
    printf("%s;%zu;%zu\n", "GtkStyleProviderIface", sizeof(GtkStyleProviderIface), alignof(GtkStyleProviderIface));
    printf("%s;%zu;%zu\n", "GtkSwitch", sizeof(GtkSwitch), alignof(GtkSwitch));
    printf("%s;%zu;%zu\n", "GtkSwitchAccessible", sizeof(GtkSwitchAccessible), alignof(GtkSwitchAccessible));
    printf("%s;%zu;%zu\n", "GtkSwitchAccessibleClass", sizeof(GtkSwitchAccessibleClass), alignof(GtkSwitchAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkSwitchClass", sizeof(GtkSwitchClass), alignof(GtkSwitchClass));
    printf("%s;%zu;%zu\n", "GtkTable", sizeof(GtkTable), alignof(GtkTable));
    printf("%s;%zu;%zu\n", "GtkTableClass", sizeof(GtkTableClass), alignof(GtkTableClass));
    printf("%s;%zu;%zu\n", "GtkTargetEntry", sizeof(GtkTargetEntry), alignof(GtkTargetEntry));
    printf("%s;%zu;%zu\n", "GtkTargetFlags", sizeof(GtkTargetFlags), alignof(GtkTargetFlags));
    printf("%s;%zu;%zu\n", "GtkTargetPair", sizeof(GtkTargetPair), alignof(GtkTargetPair));
    printf("%s;%zu;%zu\n", "GtkTearoffMenuItem", sizeof(GtkTearoffMenuItem), alignof(GtkTearoffMenuItem));
    printf("%s;%zu;%zu\n", "GtkTearoffMenuItemClass", sizeof(GtkTearoffMenuItemClass), alignof(GtkTearoffMenuItemClass));
    printf("%s;%zu;%zu\n", "GtkTextBuffer", sizeof(GtkTextBuffer), alignof(GtkTextBuffer));
    printf("%s;%zu;%zu\n", "GtkTextBufferClass", sizeof(GtkTextBufferClass), alignof(GtkTextBufferClass));
    printf("%s;%zu;%zu\n", "GtkTextBufferTargetInfo", sizeof(GtkTextBufferTargetInfo), alignof(GtkTextBufferTargetInfo));
    printf("%s;%zu;%zu\n", "GtkTextCellAccessible", sizeof(GtkTextCellAccessible), alignof(GtkTextCellAccessible));
    printf("%s;%zu;%zu\n", "GtkTextCellAccessibleClass", sizeof(GtkTextCellAccessibleClass), alignof(GtkTextCellAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkTextChildAnchor", sizeof(GtkTextChildAnchor), alignof(GtkTextChildAnchor));
    printf("%s;%zu;%zu\n", "GtkTextChildAnchorClass", sizeof(GtkTextChildAnchorClass), alignof(GtkTextChildAnchorClass));
    printf("%s;%zu;%zu\n", "GtkTextDirection", sizeof(GtkTextDirection), alignof(GtkTextDirection));
    printf("%s;%zu;%zu\n", "GtkTextExtendSelection", sizeof(GtkTextExtendSelection), alignof(GtkTextExtendSelection));
    printf("%s;%zu;%zu\n", "GtkTextIter", sizeof(GtkTextIter), alignof(GtkTextIter));
    printf("%s;%zu;%zu\n", "GtkTextMark", sizeof(GtkTextMark), alignof(GtkTextMark));
    printf("%s;%zu;%zu\n", "GtkTextMarkClass", sizeof(GtkTextMarkClass), alignof(GtkTextMarkClass));
    printf("%s;%zu;%zu\n", "GtkTextSearchFlags", sizeof(GtkTextSearchFlags), alignof(GtkTextSearchFlags));
    printf("%s;%zu;%zu\n", "GtkTextTag", sizeof(GtkTextTag), alignof(GtkTextTag));
    printf("%s;%zu;%zu\n", "GtkTextTagClass", sizeof(GtkTextTagClass), alignof(GtkTextTagClass));
    printf("%s;%zu;%zu\n", "GtkTextTagTable", sizeof(GtkTextTagTable), alignof(GtkTextTagTable));
    printf("%s;%zu;%zu\n", "GtkTextTagTableClass", sizeof(GtkTextTagTableClass), alignof(GtkTextTagTableClass));
    printf("%s;%zu;%zu\n", "GtkTextView", sizeof(GtkTextView), alignof(GtkTextView));
    printf("%s;%zu;%zu\n", "GtkTextViewAccessible", sizeof(GtkTextViewAccessible), alignof(GtkTextViewAccessible));
    printf("%s;%zu;%zu\n", "GtkTextViewAccessibleClass", sizeof(GtkTextViewAccessibleClass), alignof(GtkTextViewAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkTextViewClass", sizeof(GtkTextViewClass), alignof(GtkTextViewClass));
    printf("%s;%zu;%zu\n", "GtkTextViewLayer", sizeof(GtkTextViewLayer), alignof(GtkTextViewLayer));
    printf("%s;%zu;%zu\n", "GtkTextWindowType", sizeof(GtkTextWindowType), alignof(GtkTextWindowType));
    printf("%s;%zu;%zu\n", "GtkThemingEngine", sizeof(GtkThemingEngine), alignof(GtkThemingEngine));
    printf("%s;%zu;%zu\n", "GtkThemingEngineClass", sizeof(GtkThemingEngineClass), alignof(GtkThemingEngineClass));
    printf("%s;%zu;%zu\n", "GtkToggleAction", sizeof(GtkToggleAction), alignof(GtkToggleAction));
    printf("%s;%zu;%zu\n", "GtkToggleActionClass", sizeof(GtkToggleActionClass), alignof(GtkToggleActionClass));
    printf("%s;%zu;%zu\n", "GtkToggleActionEntry", sizeof(GtkToggleActionEntry), alignof(GtkToggleActionEntry));
    printf("%s;%zu;%zu\n", "GtkToggleButton", sizeof(GtkToggleButton), alignof(GtkToggleButton));
    printf("%s;%zu;%zu\n", "GtkToggleButtonAccessible", sizeof(GtkToggleButtonAccessible), alignof(GtkToggleButtonAccessible));
    printf("%s;%zu;%zu\n", "GtkToggleButtonAccessibleClass", sizeof(GtkToggleButtonAccessibleClass), alignof(GtkToggleButtonAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkToggleButtonClass", sizeof(GtkToggleButtonClass), alignof(GtkToggleButtonClass));
    printf("%s;%zu;%zu\n", "GtkToggleToolButton", sizeof(GtkToggleToolButton), alignof(GtkToggleToolButton));
    printf("%s;%zu;%zu\n", "GtkToggleToolButtonClass", sizeof(GtkToggleToolButtonClass), alignof(GtkToggleToolButtonClass));
    printf("%s;%zu;%zu\n", "GtkToolButton", sizeof(GtkToolButton), alignof(GtkToolButton));
    printf("%s;%zu;%zu\n", "GtkToolButtonClass", sizeof(GtkToolButtonClass), alignof(GtkToolButtonClass));
    printf("%s;%zu;%zu\n", "GtkToolItem", sizeof(GtkToolItem), alignof(GtkToolItem));
    printf("%s;%zu;%zu\n", "GtkToolItemClass", sizeof(GtkToolItemClass), alignof(GtkToolItemClass));
    printf("%s;%zu;%zu\n", "GtkToolItemGroup", sizeof(GtkToolItemGroup), alignof(GtkToolItemGroup));
    printf("%s;%zu;%zu\n", "GtkToolItemGroupClass", sizeof(GtkToolItemGroupClass), alignof(GtkToolItemGroupClass));
    printf("%s;%zu;%zu\n", "GtkToolPalette", sizeof(GtkToolPalette), alignof(GtkToolPalette));
    printf("%s;%zu;%zu\n", "GtkToolPaletteClass", sizeof(GtkToolPaletteClass), alignof(GtkToolPaletteClass));
    printf("%s;%zu;%zu\n", "GtkToolPaletteDragTargets", sizeof(GtkToolPaletteDragTargets), alignof(GtkToolPaletteDragTargets));
    printf("%s;%zu;%zu\n", "GtkToolShellIface", sizeof(GtkToolShellIface), alignof(GtkToolShellIface));
    printf("%s;%zu;%zu\n", "GtkToolbar", sizeof(GtkToolbar), alignof(GtkToolbar));
    printf("%s;%zu;%zu\n", "GtkToolbarClass", sizeof(GtkToolbarClass), alignof(GtkToolbarClass));
    printf("%s;%zu;%zu\n", "GtkToolbarSpaceStyle", sizeof(GtkToolbarSpaceStyle), alignof(GtkToolbarSpaceStyle));
    printf("%s;%zu;%zu\n", "GtkToolbarStyle", sizeof(GtkToolbarStyle), alignof(GtkToolbarStyle));
    printf("%s;%zu;%zu\n", "GtkToplevelAccessible", sizeof(GtkToplevelAccessible), alignof(GtkToplevelAccessible));
    printf("%s;%zu;%zu\n", "GtkToplevelAccessibleClass", sizeof(GtkToplevelAccessibleClass), alignof(GtkToplevelAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkTreeDragDestIface", sizeof(GtkTreeDragDestIface), alignof(GtkTreeDragDestIface));
    printf("%s;%zu;%zu\n", "GtkTreeDragSourceIface", sizeof(GtkTreeDragSourceIface), alignof(GtkTreeDragSourceIface));
    printf("%s;%zu;%zu\n", "GtkTreeIter", sizeof(GtkTreeIter), alignof(GtkTreeIter));
    printf("%s;%zu;%zu\n", "GtkTreeModelFilter", sizeof(GtkTreeModelFilter), alignof(GtkTreeModelFilter));
    printf("%s;%zu;%zu\n", "GtkTreeModelFilterClass", sizeof(GtkTreeModelFilterClass), alignof(GtkTreeModelFilterClass));
    printf("%s;%zu;%zu\n", "GtkTreeModelFlags", sizeof(GtkTreeModelFlags), alignof(GtkTreeModelFlags));
    printf("%s;%zu;%zu\n", "GtkTreeModelIface", sizeof(GtkTreeModelIface), alignof(GtkTreeModelIface));
    printf("%s;%zu;%zu\n", "GtkTreeModelSort", sizeof(GtkTreeModelSort), alignof(GtkTreeModelSort));
    printf("%s;%zu;%zu\n", "GtkTreeModelSortClass", sizeof(GtkTreeModelSortClass), alignof(GtkTreeModelSortClass));
    printf("%s;%zu;%zu\n", "GtkTreeSelection", sizeof(GtkTreeSelection), alignof(GtkTreeSelection));
    printf("%s;%zu;%zu\n", "GtkTreeSelectionClass", sizeof(GtkTreeSelectionClass), alignof(GtkTreeSelectionClass));
    printf("%s;%zu;%zu\n", "GtkTreeSortableIface", sizeof(GtkTreeSortableIface), alignof(GtkTreeSortableIface));
    printf("%s;%zu;%zu\n", "GtkTreeStore", sizeof(GtkTreeStore), alignof(GtkTreeStore));
    printf("%s;%zu;%zu\n", "GtkTreeStoreClass", sizeof(GtkTreeStoreClass), alignof(GtkTreeStoreClass));
    printf("%s;%zu;%zu\n", "GtkTreeView", sizeof(GtkTreeView), alignof(GtkTreeView));
    printf("%s;%zu;%zu\n", "GtkTreeViewAccessible", sizeof(GtkTreeViewAccessible), alignof(GtkTreeViewAccessible));
    printf("%s;%zu;%zu\n", "GtkTreeViewAccessibleClass", sizeof(GtkTreeViewAccessibleClass), alignof(GtkTreeViewAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkTreeViewClass", sizeof(GtkTreeViewClass), alignof(GtkTreeViewClass));
    printf("%s;%zu;%zu\n", "GtkTreeViewColumn", sizeof(GtkTreeViewColumn), alignof(GtkTreeViewColumn));
    printf("%s;%zu;%zu\n", "GtkTreeViewColumnClass", sizeof(GtkTreeViewColumnClass), alignof(GtkTreeViewColumnClass));
    printf("%s;%zu;%zu\n", "GtkTreeViewColumnSizing", sizeof(GtkTreeViewColumnSizing), alignof(GtkTreeViewColumnSizing));
    printf("%s;%zu;%zu\n", "GtkTreeViewDropPosition", sizeof(GtkTreeViewDropPosition), alignof(GtkTreeViewDropPosition));
    printf("%s;%zu;%zu\n", "GtkTreeViewGridLines", sizeof(GtkTreeViewGridLines), alignof(GtkTreeViewGridLines));
    printf("%s;%zu;%zu\n", "GtkUIManager", sizeof(GtkUIManager), alignof(GtkUIManager));
    printf("%s;%zu;%zu\n", "GtkUIManagerClass", sizeof(GtkUIManagerClass), alignof(GtkUIManagerClass));
    printf("%s;%zu;%zu\n", "GtkUIManagerItemType", sizeof(GtkUIManagerItemType), alignof(GtkUIManagerItemType));
    printf("%s;%zu;%zu\n", "GtkUnit", sizeof(GtkUnit), alignof(GtkUnit));
    printf("%s;%zu;%zu\n", "GtkVBox", sizeof(GtkVBox), alignof(GtkVBox));
    printf("%s;%zu;%zu\n", "GtkVBoxClass", sizeof(GtkVBoxClass), alignof(GtkVBoxClass));
    printf("%s;%zu;%zu\n", "GtkVButtonBox", sizeof(GtkVButtonBox), alignof(GtkVButtonBox));
    printf("%s;%zu;%zu\n", "GtkVButtonBoxClass", sizeof(GtkVButtonBoxClass), alignof(GtkVButtonBoxClass));
    printf("%s;%zu;%zu\n", "GtkVPaned", sizeof(GtkVPaned), alignof(GtkVPaned));
    printf("%s;%zu;%zu\n", "GtkVPanedClass", sizeof(GtkVPanedClass), alignof(GtkVPanedClass));
    printf("%s;%zu;%zu\n", "GtkVScale", sizeof(GtkVScale), alignof(GtkVScale));
    printf("%s;%zu;%zu\n", "GtkVScaleClass", sizeof(GtkVScaleClass), alignof(GtkVScaleClass));
    printf("%s;%zu;%zu\n", "GtkVScrollbar", sizeof(GtkVScrollbar), alignof(GtkVScrollbar));
    printf("%s;%zu;%zu\n", "GtkVScrollbarClass", sizeof(GtkVScrollbarClass), alignof(GtkVScrollbarClass));
    printf("%s;%zu;%zu\n", "GtkVSeparator", sizeof(GtkVSeparator), alignof(GtkVSeparator));
    printf("%s;%zu;%zu\n", "GtkVSeparatorClass", sizeof(GtkVSeparatorClass), alignof(GtkVSeparatorClass));
    printf("%s;%zu;%zu\n", "GtkViewport", sizeof(GtkViewport), alignof(GtkViewport));
    printf("%s;%zu;%zu\n", "GtkViewportClass", sizeof(GtkViewportClass), alignof(GtkViewportClass));
    printf("%s;%zu;%zu\n", "GtkVolumeButton", sizeof(GtkVolumeButton), alignof(GtkVolumeButton));
    printf("%s;%zu;%zu\n", "GtkVolumeButtonClass", sizeof(GtkVolumeButtonClass), alignof(GtkVolumeButtonClass));
    printf("%s;%zu;%zu\n", "GtkWidget", sizeof(GtkWidget), alignof(GtkWidget));
    printf("%s;%zu;%zu\n", "GtkWidgetAccessible", sizeof(GtkWidgetAccessible), alignof(GtkWidgetAccessible));
    printf("%s;%zu;%zu\n", "GtkWidgetAccessibleClass", sizeof(GtkWidgetAccessibleClass), alignof(GtkWidgetAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkWidgetClass", sizeof(GtkWidgetClass), alignof(GtkWidgetClass));
    printf("%s;%zu;%zu\n", "GtkWidgetHelpType", sizeof(GtkWidgetHelpType), alignof(GtkWidgetHelpType));
    printf("%s;%zu;%zu\n", "GtkWindow", sizeof(GtkWindow), alignof(GtkWindow));
    printf("%s;%zu;%zu\n", "GtkWindowAccessible", sizeof(GtkWindowAccessible), alignof(GtkWindowAccessible));
    printf("%s;%zu;%zu\n", "GtkWindowAccessibleClass", sizeof(GtkWindowAccessibleClass), alignof(GtkWindowAccessibleClass));
    printf("%s;%zu;%zu\n", "GtkWindowClass", sizeof(GtkWindowClass), alignof(GtkWindowClass));
    printf("%s;%zu;%zu\n", "GtkWindowGroup", sizeof(GtkWindowGroup), alignof(GtkWindowGroup));
    printf("%s;%zu;%zu\n", "GtkWindowGroupClass", sizeof(GtkWindowGroupClass), alignof(GtkWindowGroupClass));
    printf("%s;%zu;%zu\n", "GtkWindowPosition", sizeof(GtkWindowPosition), alignof(GtkWindowPosition));
    printf("%s;%zu;%zu\n", "GtkWindowType", sizeof(GtkWindowType), alignof(GtkWindowType));
    printf("%s;%zu;%zu\n", "GtkWrapMode", sizeof(GtkWrapMode), alignof(GtkWrapMode));
    return 0;
}
